Summary:       A library for using 3D graphics hardware to draw pretty pictures
Name:          cogl
Version:       1.22.8
Release:       4%{?dist}

License:       LGPLv2+
URL:           http://www.clutter-project.org/
Source0:       http://download.gnome.org/sources/cogl/1.22/cogl-%{version}.tar.xz

Patch3000:     0001-egl-Use-eglGetPlatformDisplay-not-eglGetDisplay.patch
Patch3001:     0002-add-GL_ARB_shader_texture_lod-support.patch
Patch3002:     0003-texture-support-copy_sub_image.patch

BuildRequires: chrpath make
BuildRequires: pkgconfig(cairo) pkgconfig(gbm) pkgconfig(gdk-pixbuf-2.0)
BuildRequires: mesa-libEGL-devel
BuildRequires: pkgconfig(gl) pkgconfig(glib-2.0) pkgconfig(gobject-introspection-1.0)
BuildRequires: pkgconfig(libdrm) pkgconfig(pango) pkgconfig(xcomposite)
BuildRequires: pkgconfig(xdamage) pkgconfig(xext) pkgconfig(xfixes) pkgconfig(xrandr)
BuildRequires: pkgconfig(wayland-server) pkgconfig(wayland-client) pkgconfig(wayland-cursor)
BuildRequires: pkgconfig(wayland-egl) pkgconfig(xkbcommon)

%description
Cogl is a small open source library for using 3D graphics hardware to draw
pretty pictures. The API departs from the flat state machine style of
OpenGL and is designed to make it easy to write orthogonal components that
can render without stepping on each others toes.

As well aiming for a nice API, we think having a single library as opposed
to an API specification like OpenGL has a few advantages too; like being
able to paper over the inconsistencies/bugs of different OpenGL
implementations in a centralized place, not to mention the myriad of OpenGL
extensions. It also means we are in a better position to provide utility
APIs that help software developers since they only need to be implemented
once and there is no risk of inconsistency between implementations.

Having other backends, besides OpenGL, such as drm, Gallium or D3D are
options we are interested in for the future.

%package devel
Summary:       %{name} development environment
Requires:      %{name} = %{version}-%{release}

%description devel
Header files and libraries for building and developing apps with %{name}.

%package       tests
Requires:      %{name} = %{version}-%{release}
Summary:       Tests for %{name}

%description   tests
This package contains the installable tests for %{cogl}.

%prep
%autosetup -p1

%build
CFLAGS="$RPM_OPT_FLAGS -fPIC"
%configure \
  --enable-cairo=yes \
  --enable-cogl-pango=yes \
  --enable-gdk-pixbuf=yes \
  --enable-glx=yes \
  --disable-gtk-doc \
  --enable-introspection=yes \
  --enable-kms-egl-platform \
  --enable-wayland-egl-platform \
  --enable-wayland-egl-server \
  --enable-xlib-egl-platform \
  --enable-installed-tests

%make_build

%install
%make_install

find %{buildroot} -name '*.la' -delete

rm %{buildroot}%{_datadir}/cogl/examples-data/crate.jpg

chrpath --delete %{buildroot}%{_libdir}/libcogl-path.so
chrpath --delete %{buildroot}%{_libdir}/libcogl-pango.so

%find_lang %{name}

%check
make check || :

%files -f %{name}.lang
%license COPYING
%doc NEWS README
%{_libdir}/libcogl*.so.20*
%{_libdir}/girepository-1.0/Cogl*.typelib

%files devel
%{_includedir}/cogl
%{_libdir}/libcogl*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/Cogl*.gir

%files tests
%{_datadir}/installed-tests/%{name}
%{_libexecdir}/installed-tests/%{name}

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.22.8-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.22.8-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.22.8-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Dec 6 2022 cunshunxia <cunshunxia@tencent.com> - 1.22.8-1
- initial build
